@@ -39,13 +39,29 @@ def getHubzeroConfigOption(headerName, optionName, default = None):
 
 	config.readfp(open(hubzeroConfFileLocation))
 
-        try:
+	try:
 		value = config.get(headerName, optionName)
 	except ConfigParser.NoOptionError:
 		value = default
+	except ConfigParser.NoSectionError:
+		value = default
 
 	return value
 	
 
+def setHubzeroConfigOption(headerName, optionName, optionValue):
+
+	if not os.path.exists(hubzeroConfFileLocation):
+		raise Exception("Cannot find hubzeroConfFileLocation:" + hubzeroConfFileLocation)
+
+	config = ConfigParser.ConfigParser()
+	config.readfp(open(hubzeroConfFileLocation))
+
+	if not config.has_section:
+		config.add_section(sectionName)
+
+	config.set(headerName, optionName, optionValue)
+
+
 def getHubDefaultSite():
 	return getHubzeroConfigOption("DEFAULT", "site")
