@@ -37,6 +37,30 @@ import os
 import sys
 import traceback
 
+pwhashtypes = ["{CRYPT}", "{MD5}", "{SSHA}", "{SHA}" ]
+
+
+def hashPassword(pw, hashtype = 'MD5'):
+	"""
+	We allow users to pass in pre hashed passwords or plaintext. If * is passed in,
+	that means a disabled password. No MD5 hashed password will hash to *
+
+	This function analyzes a password and returns the hashed value
+
+    Note, only md5 supported for now from here
+	"""
+	if any (pw.upper().startswith(x) for x in pwhashtypes):
+		rv = pw
+	elif pw == '*':
+		rv = '{MD5}*'
+	else:
+		if hashtype == 'MD5':
+			rv = hubzero.config.passwords.MD5PasswordHash(pw)
+		else:
+			raise Exception("hashPassword hashtype not supported:" + hashtype)
+
+	return rv
+
 
 def userExists(username, hubname = ""):
 	dbPW = hubzero.config.webconfig.getWebConfigDBPassword(hubname)
@@ -124,39 +148,24 @@ def _del_jos_xprofiles(db, uidNumber):
 
 
 def _update_jos_xprofiles_pw(db, userid, password):
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 
+	pw = hashPassword(password)
 	sql = "UPDATE `jos_xprofiles` SET `userPassword`=%s WHERE `uidNumber`=%s"
 	data = (pw, userid)
 	db.query_rowcount(sql, data)
 
 
 def _update_jos_users_pw(db, userid, password):
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 
+	pw = hashPassword(password)
 	sql = "UPDATE `jos_users` SET `password` = %s WHERE `id`=%s"
 	data = (pw, userid)
 	db.query_rowcount(sql, data)
 
 
 def _update_jos_users_password(db, userid, password):
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
 
+	pw = hashPassword(password)
 	sql = "UPDATE `jos_users_password` SET `passhash` = %s WHERE `user_id`=%s"
 	data = (pw, userid)
 	db.query_rowcount(sql, data)
@@ -170,14 +179,6 @@ def _update_ldap_user_pw(username, uidNumber, password):
 	"""
 	Pass raw pw here, we'll hash it
 	"""
-
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to? We think not
-
 	hubLDAPAcctMgrDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerdn")
 	hubLDAPAcctMgrPW = hubzero.config.webconfig.getComponentParam("com_system", "ldap_managerpw")
 	hubLDAPBaseDN = hubzero.config.webconfig.getComponentParam("com_system", "ldap_basedn")	
@@ -186,6 +187,8 @@ def _update_ldap_user_pw(username, uidNumber, password):
 	l = ldap.initialize(ldapServer)
 	l.simple_bind_s(hubLDAPAcctMgrDN, hubLDAPAcctMgrPW)
 
+	pw = hashPassword(password)
+
 	dn = "uid=" + username + ",ou=users," + hubLDAPBaseDN
 
 	attrs = [ (ldap.MOD_REPLACE, 'userPassword', pw) ]
@@ -195,12 +198,7 @@ def _update_ldap_user_pw(username, uidNumber, password):
 
 def _insert_jos_users(db, joomlauserid, name, username, email, password, jgidNumber):
 
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to '*'? we think not
+	pw = hashPassword(password)
 
 	# xlate numeric jgidNumber to the string (Joomla needs both for some reason)
 	# 18=Registered, 23=Manager, 24=Administrator, 25=Super Administrator
@@ -251,12 +249,7 @@ def _insert_jos_user_usergroup_map(db, userID, groupID = 2):
 
 def _insert_jos_xprofiles(db, hubname, uidNumber, fname, mname, lname, username, email, password, gid, gidNumber, loginShell, homeDir):
 
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to, we think not '*'?
+	pw = hashPassword(password)
 
 	sql = "INSERT INTO `jos_xprofiles` (`uidNumber`, `name`, `username`, `email`, `registerDate`, `gidNumber`, `homeDirectory`, `loginShell`, "
 	sql += "`ftpShell`, `userPassword`, `gid`, `orgtype`, `organization`, `countryresident`, `countryorigin`, `gender`, `url`, `reason`, "
@@ -314,13 +307,7 @@ def add_ldap_user(uid,
 	attrs['objectclass'] = ['top', 'account', 'posixAccount', 'shadowAccount']  
 	attrs['cn'] = str(uid)
 
-	if password != '*':
-		attrs['userPassword'] = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		attrs['userPassword'] = password
-	else:
-		attrs['userPassword'] = '{MD5}*' # can user generate a value that will MD5 hash to '*'?, we think not 
-
+	attrs['userPassword'] = hashPassword(password)
 	attrs['uid'] = uid
 	attrs['uidNumber'] = str(uidNumber)
 	attrs['homeDirectory'] = homeDir
@@ -547,12 +534,7 @@ def updateUserPW(username, password, updateCMS = True, updateLDAP = True, hubnam
 
 	userid = _getUserID(db, username)
 
-	if password != '*':
-		pw = hubzero.config.passwords.MD5PasswordHash(password)
-	elif '{MD5}' in password:
-		pw = password
-	else:
-		pw = '{MD5}*' # can user generate a value that will MD5 hash to '*'? We think not.
+	pw = hashPassword(password)
 
 	if updateCMS:
 		_update_jos_xprofiles_pw(db, userid, pw)
